==> nextcloud-30.0.10.tgz: nextcloud/apps/files_reminders/l10n/cs.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Připomínky souborů",
    "Reminder for {name}" : "Připomínka ohledně {name}",
    "View file" : "Zobrazit soubor",
    "View folder" : "Zobrazit složku",
    "Files reminder" : "Připomínka souboru",
    "The \"files_reminders\" app can work properly." : "Aplikace „files_reminder“ může fungovat správně.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace „files_reminder“ potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder.",
    "Set file reminders" : "Nastavit připomínky souborů",
    "Set reminder for \"{fileName}\"" : "Nastavit připomínku pro „{fileName}",
    "Set reminder at custom date & time" : "Nastavit připomínku na uživatelsky určené datum a čas",
    "Clear reminder" : "Vyčistit připomínku",
    "Please choose a valid date & time" : "Zvolte platný datum a čas",
    "Reminder set for \"{fileName}\"" : "Nastavena připomínka ohledně „{fileName}“",
    "Failed to set reminder" : "Připomínku se nepodařilo nastavit",
    "Reminder cleared for \"{fileName}\"" : "Připomínka ohledně „{fileName}“ vyčištěna",
    "Failed to clear reminder" : "Připomínku se nepodařilo vyčistit",
    "We will remind you of this file" : "Připomeneme vám tento soubor",
    "Cancel" : "Storno",
    "Set reminder" : "Nastavit připomínku",
    "Reminder set" : "Nastavit připomínku",
    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku",
    "Later today" : "Později dnes",
    "Set reminder for later today" : "Nastavit připomínku na později dnes",
    "Tomorrow" : "Zítra",
    "Set reminder for tomorrow" : "Nastavit připomínku na zítra",
    "This weekend" : "Tento víkend",
    "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
    "Next week" : "Příští týden",
    "Set reminder for next week" : "Nastavit připomínku pro příští týden",
    "This files_reminder can work properly." : "Tento files_reminder může fungovat správně.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace files_reminder potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-31.0.12.tgz: nextcloud/apps/files_reminders/l10n/cs.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Připomínky souborů",
    "Reminder for {name}" : "Připomínka ohledně {name}",
    "View file" : "Zobrazit soubor",
    "View folder" : "Zobrazit složku",
    "Files reminder" : "Připomínka souboru",
    "The \"files_reminders\" app can work properly." : "Aplikace „files_reminder“ může fungovat správně.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace „files_reminder“ potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder.",
    "Set file reminders" : "Nastavit připomínky souborů",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Připomínky souborů**\n\nNastavení připomínek souborů.\n\nPoznámka: Pro používání aplikace `Připomínky souborů` se ujistěte, že aplikace `Notifications` je nainstalována a povolena, protože poskytuje potřebná API pro správnou funkčnost.",
    "Please choose a valid date & time" : "Zvolte platný datum a čas",
    "Reminder set for \"{fileName}\"" : "Nastavena připomínka ohledně „{fileName}“",
    "Failed to set reminder" : "Připomínku se nepodařilo nastavit",
    "Reminder cleared for \"{fileName}\"" : "Připomínka ohledně „{fileName}“ vyčištěna",
    "Failed to clear reminder" : "Připomínku se nepodařilo vyčistit",
    "Reminder at custom date & time" : "Připomínka v uživatelsky určený datum a čas",
    "We will remind you of this file" : "Připomeneme vám tento soubor",
    "Cancel" : "Storno",
    "Clear reminder" : "Vyčistit připomínku",
    "Set reminder" : "Nastavit připomínku",
    "Set reminder for " : "Nastavit připomínku pro",
    "Reminder set" : "Nastavit připomínku",
    "Custom reminder" : "Uživatelsky určená připomínka",
    "Later today" : "Později dnes",
    "Set reminder for later today" : "Nastavit připomínku na později dnes",
    "Tomorrow" : "Zítra",
    "Set reminder for tomorrow" : "Nastavit připomínku na zítra",
    "This weekend" : "Tento víkend",
    "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
    "Next week" : "Příští týden",
    "Set reminder for next week" : "Nastavit připomínku pro příští týden",
    "This files_reminder can work properly." : "Tento files_reminder může fungovat správně.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace files_reminder potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder.",
    "Set reminder for \"{fileName}\"" : "Nastavit připomínku pro „{fileName}",
    "Set reminder at custom date & time" : "Nastavit připomínku na uživatelsky určené datum a čas",
    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
